@@ -61,6 +61,7 @@ void VaultsModel::Private::loadData()
         vaultKeys.clear();
         busyVaults.clear();
         errorVaults.clear();
+        openVaults.clear();
 
         for (const auto &vault : vaultList) {
             vaults[vault.device] = vault;
@@ -70,6 +71,10 @@ void VaultsModel::Private::loadData()
                 busyVaults << vault.device;
             }
 
+            if (vault.isOpened()) {
+                openVaults << vault.device;
+            }
+
             if (!vault.message.isEmpty()) {
                 errorVaults << vault.device;
             }
@@ -82,6 +87,7 @@ void VaultsModel::Private::loadData()
         }
 
         Q_EMIT q->isBusyChanged(busyVaults.count() != 0);
+        Q_EMIT q->hasOpenVaultsChanged(openVaults.count() != 0);
         Q_EMIT q->hasErrorChanged(errorVaults.count() != 0);
     });
 }
@@ -161,6 +167,19 @@ void VaultsModel::Private::onVaultChanged(const PlasmaVault::VaultInfo &vaultInf
         }
     }
 
+    // Let's see whether this warrants updates to the opened flag
+    if (vaultInfo.isOpened() && !openVaults.contains(device)) {
+        openVaults << device;
+        Q_EMIT q->hasOpenVaultsChanged(true);
+    }
+
+    if (!vaultInfo.isOpened() && openVaults.contains(device)) {
+        openVaults.remove(device);
+        if (openVaults.count() == 0) {
+            Q_EMIT q->hasOpenVaultsChanged(false);
+        }
+    }
+
     vaults[device] = vaultInfo;
     q->dataChanged(q->index(row), q->index(row));
 }
@@ -346,6 +365,11 @@ bool VaultsModel::hasError() const
     return !d->errorVaults.isEmpty();
 }
 
+bool VaultsModel::hasOpenVaults() const
+{
+    return !d->openVaults.isEmpty();
+}
+
 SortedVaultsModelProxy::SortedVaultsModelProxy(QObject *parent)
     : QSortFilterProxyModel(parent)
     , m_source(new VaultsModel(this))
